@@ -18,6 +18,7 @@
 #' \item \code{R0} Unfished recruitment
 #' \item \code{vul_par} A length-two vector for the age of 95\% and 50\% fleet selectivity. Fixed to maturity otherwise.
 #' }
+#' @param prior A named list for the parameters of any priors to be added to the model. See details in \code{SCA_Pope}.
 #' @param silent Logical, passed to \code{\link[TMB]{MakeADFun}}, whether TMB
 #' will print trace information during optimization. Used for diagnostics for model convergence.
 #' @param opt_hess Logical, whether the hessian function will be passed to \code{\link[stats]{nlminb}} during optimization
@@ -41,7 +42,8 @@
 #' @useDynLib SAMtool
 #' @export
 SSS <- function(x = 1, Data, dep = 0.4, SR = c("BH", "Ricker"), 
-                rescale = "mean1", start = NULL, silent = TRUE, opt_hess = FALSE, n_restart = ifelse(opt_hess, 0, 1),
+                rescale = "mean1", start = NULL, prior = list(),
+                silent = TRUE, opt_hess = FALSE, n_restart = ifelse(opt_hess, 0, 1),
                 control = list(iter.max = 2e5, eval.max = 4e5), ...) {
   
   catch_eq <- "Pope"
@@ -51,7 +53,7 @@ SSS <- function(x = 1, Data, dep = 0.4, SR = c("BH", "Ricker"),
   dep <- eval(dep)
   SR <- match.arg(SR)
 
-  if(any(names(dots) == "yind")) {
+  if (any(names(dots) == "yind")) {
     yind <- eval(dots$yind)
   } else {
     yind <- which(!is.na(Data@Cat[x, ]))[1]
@@ -59,7 +61,7 @@ SSS <- function(x = 1, Data, dep = 0.4, SR = c("BH", "Ricker"),
   }
   Year <- Data@Year[yind]
   C_hist <- Data@Cat[x, yind]
-  if(any(is.na(C_hist) | C_hist < 0)) warning("Error. Catch time series is not complete.")
+  if (any(is.na(C_hist) | C_hist < 0)) warning("Error. Catch time series is not complete.")
 
   n_y <- length(C_hist)
   I_hist <- matrix(NA_real_, n_y, 1)
@@ -68,7 +70,7 @@ SSS <- function(x = 1, Data, dep = 0.4, SR = c("BH", "Ricker"),
 
   max_age <- as.integer(-log(0.01)/Data@Mort[x])
   n_age <- max_age + 1
-  if(any(names(dots) == "M_at_age") && dots$M_at_age) {
+  if (any(names(dots) == "M_at_age") && dots$M_at_age) {
     M <- Data@Misc$StockPars$M_ageArray[x, , n_y] * Data@Obs$Mbias[x]
     prior$M <- NULL
   } else {
@@ -86,8 +88,11 @@ SSS <- function(x = 1, Data, dep = 0.4, SR = c("BH", "Ricker"),
   mat_age <- c(0, 1/(1 + exp(-log(19) * (c(1:max_age) - A50)/(A95 - A50))))
   mat_age <- mat_age/max(mat_age)
   LH <- list(LAA = La, WAA = Wa, Linf = Linf, K = K, t0 = t0, a = a, b = b, A50 = A50, A95 = A95)
-
-  if(rescale == "mean1") rescale <- 1/mean(C_hist)
+  
+  # Generate priors
+  prior <- make_prior(prior, nsurvey = 0, ifelse(SR == "BH", 1, 2), msg = FALSE)
+  if (rescale == "mean1") rescale <- 1/mean(C_hist)
+  
   data <- list(model = "SCA", C_hist = C_hist, rescale = rescale, 
                I_hist = I_hist, I_sd = matrix(0.01, n_y, 1), I_units = 1, I_vul = matrix(1, n_age, 1), 
                abs_I = 0, nsurvey = 1, LWT = 1,
@@ -97,36 +102,37 @@ SSS <- function(x = 1, Data, dep = 0.4, SR = c("BH", "Ricker"),
                weight = Wa, PLA = matrix(1, n_age, 1), mat = mat_age, vul_type = "logistic",
                SR_type = SR, comp_dist = "multinomial", catch_eq = catch_eq,
                est_early_rec_dev = rep(0, n_age - 1), est_rec_dev = rep(0, n_y), yindF = 0,
-               tv_M = "none", M_bounds = c(0, 1e4), use_prior = rep(0, 4), prior_dist = matrix(NA, 4, 2))
-  if(any(names(dots) == "M_at_age") && dots$M_at_age) data$M_data <- M
+               tv_M = "none", M_bounds = c(0, 1e4), use_prior = prior$use_prior, prior_dist = prior$pr_matrix,
+               sim_process_error = 0L)
+  if (any(names(dots) == "M_at_age") && dots$M_at_age) data$M_data <- M
 
   # Starting values
   params <- list()
-  if(!is.null(start)) {
-    if(!is.null(start$R0) && is.numeric(start$R0)) params$R0x <- log(start$R0[1] * rescale)
-    if(!is.null(start$h) && is.numeric(start$h)) {
-      if(SR == "BH") {
+  if (!is.null(start)) {
+    if (!is.null(start$R0) && is.numeric(start$R0)) params$R0x <- log(start$R0[1] * rescale)
+    if (!is.null(start$h) && is.numeric(start$h)) {
+      if (SR == "BH") {
         h_start <- (start$h[1] - 0.2)/0.8
         params$transformed_h <- logit(h_start)
       } else {
         params$transformed_h <- log(start$h[1] - 0.2)
       }
     }
-    if(!is.null(start$vul_par) && is.numeric(start$vul_par)) {
-      if(start$vul_par[1] > 0.75 * max_age) stop("start$vul_par[1] needs to be less than 0.75 * Data@MaxAge (see help).")
-      if(length(start$vul_par) < 2) stop("Two parameters needed for start$vul_par with logistic vulnerability (see help).")
-      if(start$vul_par[1] <= start$vul_par[2]) stop("start$vul_par[1] needs to be greater than start$vul_par[2] (see help).")
+    if (!is.null(start$vul_par) && is.numeric(start$vul_par)) {
+      if (start$vul_par[1] > 0.75 * max_age) stop("start$vul_par[1] needs to be less than 0.75 * Data@MaxAge (see help).")
+      if (length(start$vul_par) < 2) stop("Two parameters needed for start$vul_par with logistic vulnerability (see help).")
+      if (start$vul_par[1] <= start$vul_par[2]) stop("start$vul_par[1] needs to be greater than start$vul_par[2] (see help).")
 
       params$vul_par <- c(logit(start$vul_par[1]/max_age/0.75), log(start$vul_par[1] - start$vul_par[2]))
     }
   }
 
-  if(is.null(params$R0x)) {
+  if (is.null(params$R0x)) {
     params$R0x <- ifelse(is.null(Data@OM$R0[x]), log(mean(data$C_hist)) + 4, log(1.5 * rescale * Data@OM$R0[x]))
   }
-  if(is.null(params$transformed_h)) {
+  if (is.null(params$transformed_h)) {
     h_start <- Data@steep[x]
-    if(SR == "BH") {
+    if (SR == "BH") {
       h_start <- (h_start - 0.2)/0.8
       params$transformed_h <- logit(h_start)
     } else {
@@ -137,17 +143,18 @@ SSS <- function(x = 1, Data, dep = 0.4, SR = c("BH", "Ricker"),
   params$logit_M_walk <- rep(0, n_y)
   params$F_equilibrium <- 0 
   
-  if(is.null(params$vul_par)) params$vul_par <- c(logit(min(A95, 0.74 * max_age)/max_age/0.75), log(A95-A50))
+  if (is.null(params$vul_par)) params$vul_par <- c(logit(min(A95, 0.74 * max_age)/max_age/0.75), log(A95-A50))
 
   params$log_F_dev <- rep(0, n_y)
-  params$log_omega <- params$log_tau <- params$log_tau_M <- 0
+  params$log_omega <- params$log_tau <- params$log_tau_M <- log(0.01)
   params$log_early_rec_dev <- rep(0, n_age - 1)
   params$log_rec_dev <- rep(0, n_y)
 
   info <- list(Year = Year, data = data, params = params, LH = LH, control = control)
 
   map <- list()
-  map$transformed_h <- map$log_M0 <- factor(NA)
+  if (!prior$use_prior[2]) map$transformed_h <- factor(NA)
+  if (!prior$use_prior[3]) map$log_M0 <- factor(NA)
   map$logit_M_walk <- factor(rep(NA, n_y))
   map$F_equilibrium <- factor(NA)
   map$vul_par <- factor(c(NA, NA))
@@ -161,8 +168,8 @@ SSS <- function(x = 1, Data, dep = 0.4, SR = c("BH", "Ricker"),
 
   # Add starting values for rec-devs and increase R0 start value if U is too high (> 0.975)
   high_U <- try(obj$report(obj$par)$penalty > 0, silent = TRUE)
-  if(!is.character(high_U) && !is.na(high_U) && high_U) {
-    while(obj$par["R0x"] < 30 && obj$report(obj$par)$penalty > 0) {
+  if (!is.character(high_U) && !is.na(high_U) && high_U) {
+    while (obj$par["R0x"] < 30 && obj$report(obj$par)$penalty > 0) {
       obj$par["R0x"] <- obj$par["R0x"] + 1
     }
   }
@@ -174,7 +181,7 @@ SSS <- function(x = 1, Data, dep = 0.4, SR = c("BH", "Ricker"),
 
   Yearplusone <- c(Year, max(Year) + 1)
   
-  report$dynamic_SSB0 <- SCA_dynamic_SSB0(obj, data = info$data, params = info$params, map = map) %>% 
+  report$dynamic_SSB0 <- SCA_dynamic_SSB0(obj) %>% 
     structure(names = Yearplusone)
   
   nll_report <- ifelse(is.character(opt), ifelse(integrate, NA, report$nll), opt$objective)
@@ -204,7 +211,7 @@ SSS <- function(x = 1, Data, dep = 0.4, SR = c("BH", "Ricker"),
   Assessment@h <- report$h
   Assessment@U <- structure(report$U, names = Year)
   
-  if(Assessment@conv) {
+  if (Assessment@conv) {
     ref_pt <- ref_pt_SCA(obj = obj, report = report)
     report <- c(report, ref_pt[1:6])
     
